"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConstructableTWIInterface = exports.TWISlaveInterface = exports.TWIMasterInterface = void 0;
const tiny_typed_emitter_1 = require("tiny-typed-emitter");
const InterfaceType = 'twi';
const InterfaceTypeSlave = 'twiSlave';
const InterfaceTypeMaster = 'twiMaster';
class TWIMasterInterface extends tiny_typed_emitter_1.TypedEmitter {
    constructor(configuration) {
        super();
        this.interfaceType = InterfaceTypeMaster;
        this.configuration = configuration;
    }
    retransmit() {
        throw new Error('Method not implemented.');
    }
    // TODO: add real implementation
    downstreamData(data) {
        console.log(data);
    }
    sendByte(byte) {
        const data = { type: 'SendByte', byte: byte };
        this.emit('upstreamData', data);
        this.downstreamData(data);
    }
    sendAddress(address, read) {
        const data = {
            type: 'SendAddress',
            address: address,
            read: read,
        };
        this.emit('upstreamData', data);
        this.downstreamData(data);
    }
}
exports.TWIMasterInterface = TWIMasterInterface;
class TWISlaveInterface extends tiny_typed_emitter_1.TypedEmitter {
    constructor(configuration) {
        super();
        this.interfaceType = InterfaceTypeSlave;
        this.configuration = configuration;
    }
    retransmit() {
        throw new Error('Method not implemented.');
    }
    // TODO: add real implementation
    downstreamData(data) {
        console.log(data);
    }
    prepareByte(byte) {
        const data = { type: 'PrepareByte', byte: byte };
        this.emit('upstreamData', data);
        this.downstreamData(data);
    }
}
exports.TWISlaveInterface = TWISlaveInterface;
class ConstructableTWIInterface {
    constructor(signals) {
        this.interfaceType = InterfaceType;
        this.signals = signals;
    }
    getDescription() {
        return {
            availableSignals: { twi: this.signals },
        };
    }
    create(configuration) {
        if (configuration.isMaster) {
            return new TWIMasterInterface(configuration);
        }
        else {
            return new TWISlaveInterface(configuration);
        }
    }
}
exports.ConstructableTWIInterface = ConstructableTWIInterface;
//# sourceMappingURL=connectionInterface.js.map